import wx

class ExFrame(wx.Frame):
    def __init__(self, parent, title):
        super(ExFrame, self).__init__(parent, title=title, size=(300, 250))

        # 라벨과 텍스트박스 컴포넌트 배치하기
        panel = wx.Panel(self) 	# 패널: 컴포넌트를 포함하는 컨테이너 역할
        wx.StaticText(panel, label='메세지1 : ', pos=(10, 5)) 	# StaticText(라벨)이 위치할 좌표 지정
        wx.StaticText(panel, label='메세지2 : ', pos=(10, 40))
        self.txtA = wx.TextCtrl(panel, pos=(70, 5)) 	# 패널에 자료 입력용 TextCtrl 배치
        self.txtB = wx.TextCtrl(panel, pos=(70, 40)) 	# 키보드로 자료 입력 기능을 제공하기 위해서이다.

        # 메뉴 작성 - 메뉴바에 메뉴를 등록하고 메뉴에 메뉴 아이템 등록
        menuBar = wx.MenuBar()	# 메뉴바: 주메뉴를 포함
        mnuFile = wx.Menu()  	# 주메뉴 작성: 부메뉴를 포함
        mnuNew = mnuFile.Append(wx.ID_NEW, '새문서') 	# 메뉴 아이템(주메뉴에 부메뉴를 등록)
        mnuOpen = mnuFile.Append(wx.ID_OPEN, '열기 \tCtrl+O') 	# 부메뉴를 등록한다
        mnuFile.AppendSeparator()	# 메뉴 구분선 삽입
        mnuExit = mnuFile.Append(wx.ID_EXIT, '종료') 	# 부메뉴
        menuBar.Append(mnuFile, '파일(&F)') 	# 메뉴바에 주메뉴 등록. 메뉴의 문자에 &를 붙이면 access key가 된다
        self.SetMenuBar(menuBar) 	# 메뉴바를 프레임에 등록한다.

        # 메뉴에 이벤트가 발생하면 처리할 이벤트 핸들러 메소드 매칭하기
        self.Bind(wx.EVT_MENU, self.OnEvent1, mnuNew) 	# OnEvent1 핸들러 메소드와 연결한다.
        self.Bind(wx.EVT_MENU, self.OnEvent2, mnuOpen) 	# OnEvent2 핸들러 메소드와 연결한다.
        self.Bind(wx.EVT_MENU, self.OnEvent3, mnuExit) 	# OnEvent3 핸들러 메소드와 연결한다.

        btn1 = wx.Button(panel, label='버튼 1', pos=(10, 100)) 	# 패널의 지정된 좌표에 버튼 1, 2를 배치한다.
        btn2 = wx.Button(panel, label='버튼 2', pos=(100, 100))

        # 버튼에 이벤트를 장착하고 버튼 이벤트 처리하기 방법1
        btn1.Bind(wx.EVT_BUTTON, self.OnBtn1) 	# 버튼에 OnBtn1 핸들러 메소드 연결
        btn2.Bind(wx.EVT_BUTTON, self.OnBtn2) 	# 버튼에 OnBtn2 핸들러 메소드 연결

        btn3 = wx.Button(panel, label='버튼 3', pos=(10, 150)) 	# 패널에 버튼3, 4를 배치
        btn4 = wx.Button(panel, label='버튼 4', pos=(100, 150))

        #버튼에 이벤트를 장착하고 버튼 이벤트 처리하기 방법2
        btn3.Bind(wx.EVT_BUTTON, self.OnBtnProcess) 	# 여러 버튼에 처리 메소드 한 개를 연결
        btn4.Bind(wx.EVT_BUTTON, self.OnBtnProcess)
        btn3.id = 1;  btn4.id = 2	# 각 버튼을 구분하기 위해 id를 준다.

        self.Center()	# 윈도우가 모니터 중앙에 위치하도록 한다.

    # 이벤트 핸들러 메소드는 event 매개변수를 준다. 왜? 이벤트 처리시 발생 정보를 기억한다.
    def OnEvent1(self, event): 	# mnuNew 메뉴에 클릭 이벤트가 발생하면 실행된다.
        self.txtA.SetLabelText('새문서 메뉴 선택')
        self.txtB.SetLabelText('')

    def OnEvent2(self, event): 	# mnuOpen 메뉴에 클릭 이벤트가 발생하면 실행된다.
        self.txtA.SetLabelText('')
        self.txtB.SetLabelText('열기 메뉴 선택')

    def OnEvent3(self, event): 	# mnuExit 메뉴에 클릭 이벤트가 발생하면 실행된다.
        self.Close()	# 실행 중인 Frame 닫기

    def OnBtn1(self, event): 	# btn1 버튼에 클릭 이벤트가 발생하면 실행된다.
        self.txtA.SetLabelText('버튼1 선택')

    def OnBtn2(self, event): 	# btn2 버튼에 클릭 이벤트가 발생하면 실행된다.
        self.txtA.SetLabelText('버튼2 선택')

    def OnBtnProcess(self, event): 	# btn3, btn4 버튼에 클릭 이벤트가 발생하면 실행된다.
        if event.GetEventObject().id == 1: self.txtB.SetLabelText('버튼3 선택')
        elif event.GetEventObject().id == 2: self.txtB.SetLabelText('버튼4 선택')

if __name__ == '__main__':
    app = wx.App()
    ExFrame(None, '윈도우연습').Show()
    app.MainLoop()	# 프레임을 종료할 때까지 무한루핑
